@@ -40,19 +40,19 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_BufferingOptions.setLayout(&m_BufferingOptionLayout);
 
     //set up login-related options
-
-    m_SaveCredentials.setText(tr("Remember UserID and password"));
     m_LoginOptionLayout.addWidget(&m_SaveCredentials,0,0,1,-1);
     m_LoginOptions.setLayout(&m_LoginOptionLayout);
 
 
     //set up bitrate selection value button / selector
 
-    QStringListModel *pBitrateListModel = new QStringListModel(this);
-
     m_bitrateList << tr("Low bitrate (96kbps)") << tr("Standard bitrate (160kbps)")
             << tr("High bitrate (320kbps)");
 
+#ifdef Q_WS_MAEMO_5
+
+    QStringListModel *pBitrateListModel = new QStringListModel(this);
+
     pBitrateListModel->setStringList(m_bitrateList);
 
     m_pPreferredBitrateSelector = new QMaemo5ListPickSelector(this);
@@ -60,14 +60,22 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_PreferredBitrateBtn.setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered); // Maemo5 style guide wants the menu entries centered.
     m_PreferredBitrateBtn.setPickSelector(m_pPreferredBitrateSelector);
 
-    //set up UI language value button / selector
+#else
 
-    QStringListModel *pLangListModel = new QStringListModel(this);
+    m_PreferredBitrateCombo.addItems(m_bitrateList);
+
+#endif
+
+    //set up UI language value button / selector
 
     m_UILangList << "English" << "Suomi" << "Dutch" << "German"; //possible UI language values
 
     m_UILangCodeList << "en" << "fi" << "nl" << "de"; //corresponding internal language codes
 
+#ifdef Q_WS_MAEMO_5
+
+    QStringListModel *pLangListModel = new QStringListModel(this);
+
     pLangListModel->setStringList(m_UILangList);
 
     m_pUILangSelector = new QMaemo5ListPickSelector(this);
@@ -76,12 +84,20 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_UILangBtn.setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered); // Maemo5 style guide wants the menu entries centered.
     m_UILangBtn.setPickSelector(m_pUILangSelector);
 
+#else
+
+    m_UILangCombo.addItems(m_UILangList);
+
+#endif
+
     //set up screen orientation value button / selector
 
-    QStringListModel *pListModel = new QStringListModel(this);
-
     m_orientationList << tr("Landscape") << tr("Portrait") << tr("Automatic");
 
+#ifdef Q_WS_MAEMO_5
+
+    QStringListModel *pListModel = new QStringListModel(this);
+
     pListModel->setStringList(m_orientationList);
 
     m_pOrientationSelector = new QMaemo5ListPickSelector(this);
@@ -90,6 +106,12 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_OrientationBtn.setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered); // Maemo5 style guide wants the menu entries centered.
     m_OrientationBtn.setPickSelector(m_pOrientationSelector);
 
+#else
+
+    m_OrientationCombo.addItems(m_orientationList);
+
+#endif
+
     m_PlaylistLoadingTOInput.setInputMask("900");
 
     m_LastFMUserIDInput.setInputMethodHints(Qt::ImhNoAutoUppercase);
@@ -111,12 +133,19 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
     m_GridLayout.addWidget(&m_SearchOptions,0,0,1,-1);
     m_GridLayout.addWidget(&m_BufferingOptions,1,0,1,-1);
     m_GridLayout.addWidget(&m_LoginOptions,2,0,1,-1);
-    m_GridLayout.addWidget(&m_PreferredBitrateBtn,3,0,1,-1);
-    m_GridLayout.addWidget(&m_UILangBtn,4,0,1,-1);
-    m_GridLayout.addWidget(&m_OrientationBtn,5,0,1,-1);
-    m_GridLayout.addWidget(&m_PlaylistOptions,6,0,1,-1);
-    m_GridLayout.addWidget(&m_PauseOnHSDisconnSelection,7,0,1,-1);
-    m_GridLayout.addWidget(&m_ScrobblingOptions,8,0,1,-1);
+    m_GridLayout.addWidget(&m_HideCoverArt,3,0,1,-1);
+#ifdef Q_WS_MAEMO_5
+    m_GridLayout.addWidget(&m_PreferredBitrateBtn,4,0,1,-1);
+    m_GridLayout.addWidget(&m_UILangBtn,5,0,1,-1);
+    m_GridLayout.addWidget(&m_OrientationBtn,6,0,1,-1);
+#else
+    m_GridLayout.addWidget(&m_PreferredBitrateCombo,4,0,1,-1);
+    m_GridLayout.addWidget(&m_UILangCombo,5,0,1,-1);
+    m_GridLayout.addWidget(&m_OrientationCombo,6,0,1,-1);
+#endif
+    m_GridLayout.addWidget(&m_PlaylistOptions,7,0,1,-1);
+    m_GridLayout.addWidget(&m_PauseOnHSDisconnSelection,8,0,1,-1);
+    m_GridLayout.addWidget(&m_ScrobblingOptions,9,0,1,-1);
 
     m_MainAreaLayout.setLayout(&m_GridLayout);
     m_MainArea.setWidget(&m_MainAreaLayout);
@@ -145,9 +174,11 @@ void SettingsDialog::setCapsLandscape()
     m_BufferingOptions.setTitle(tr("Buffering settings"));
     m_MinBufferLenCaption.setText(tr("Min. buffering length (secs)"));
     m_PreBufferNextTrackSelection.setText(tr("Enable track pre-buffering"));
+#ifdef Q_WS_MAEMO_5
     m_PreferredBitrateBtn.setText(tr("Preferred bitrate"));
     m_UILangBtn.setText(tr("UI Language"));
     m_OrientationBtn.setText(tr("Display orientation"));
+#endif
     m_PlaylistOptions.setTitle(tr("Playlist options"));
     m_PlaylistLoadingTOCaption.setText(tr("Playlist load timeout (secs)"));
     m_PauseOnHSDisconnSelection.setText(tr("Pause on headset unplugged"));
@@ -156,6 +187,8 @@ void SettingsDialog::setCapsLandscape()
     m_LastFMUserIDCaption.setText(tr("Last.fm username"));
     m_LastFMPasswordCaption.setText(tr("Last.fm password"));
     m_SaveSettingsBtn.setText(tr("Save"));
+    m_HideCoverArt.setText(tr("Hide coverart in Now Playing"));
+    m_SaveCredentials.setText(tr("Remember UserID and password"));
 }
 
 void SettingsDialog::setCapsPortrait()
@@ -170,9 +203,11 @@ void SettingsDialog::setCapsPortrait()
     m_BufferingOptions.setTitle(tr("Buffering settings"));
     m_MinBufferLenCaption.setText(tr("Min.buff.length (secs)"));
     m_PreBufferNextTrackSelection.setText(tr("Enable track pre-buff."));
+#ifdef Q_WS_MAEMO_5
     m_PreferredBitrateBtn.setText(tr("Preferred bitrate"));
     m_UILangBtn.setText(tr("UI Language"));
     m_OrientationBtn.setText(tr("Display orientation"));
+#endif
     m_PlaylistOptions.setTitle(tr("Playlist options"));
     m_PlaylistLoadingTOCaption.setText(tr("Playlist load TO (secs)"));
     m_PauseOnHSDisconnSelection.setText(tr("Pause on headset unplugged"));
@@ -181,6 +216,8 @@ void SettingsDialog::setCapsPortrait()
     m_LastFMUserIDCaption.setText(tr("Last.fm username"));
     m_LastFMPasswordCaption.setText(tr("Last.fm password"));
     m_SaveSettingsBtn.setText(tr("Save"));
+    m_SaveCredentials.setText(tr("Remember UserID and password"));
+    m_HideCoverArt.setText(tr("Hide coverart in Now Playing"));
 }
 
 void SettingsDialog::readSettings()
@@ -221,15 +258,36 @@ void SettingsDialog::readSettings()
             m_SaveCredentials.setChecked(false);
         }
 
+        m_hideCoverart = m_pAppSettings->value("QSpot/HideCoverart",HIDE_COVERART_DEFAULT).toInt();
+        if(m_hideCoverart)
+        { //set hide coverart checkbox
+            m_HideCoverArt.setChecked(true);
+        }
+        else
+        {
+            m_HideCoverArt.setChecked(false);
+        }
+
         m_prefBitrate = m_pAppSettings->value("QSpot/PrefBitrate",IDX_BITRATE_160k).toInt();
+#ifdef Q_WS_MAEMO_5
         m_pPreferredBitrateSelector->setCurrentIndex(m_prefBitrate);
+#else
+        m_PreferredBitrateCombo.setCurrentIndex(m_prefBitrate);
+#endif
 
         m_currUILang = m_UILangCodeList.indexOf(m_pAppSettings->value("QSpot/language",LANG_DEFAULT).toString());
+#ifdef Q_WS_MAEMO_5
         m_pUILangSelector->setCurrentIndex(m_currUILang);
+#else
+        m_UILangCombo.setCurrentIndex(m_currUILang);
+#endif
 
         m_currOrientation = m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt();
-
+#ifdef Q_WS_MAEMO_5
         m_pOrientationSelector->setCurrentIndex(m_currOrientation);
+#else
+        m_OrientationCombo.setCurrentIndex(m_currOrientation);
+#endif
 
         m_playlistLoadingTO = m_pAppSettings->value("QSpot/playlistLoadingTO",PLAYLIST_LOADING_TO_DEFAULT).toInt();
         m_PlaylistLoadingTOInput.setText(QString::number(m_playlistLoadingTO));
@@ -268,6 +326,7 @@ void SettingsDialog::saveSettings()
     //save (modified) settings
 
     bool settingsChanged = false;
+    qint32 selBitrate, selUILang, selOrientation;
 
     if(m_pAppSettings)
     {
@@ -321,21 +380,60 @@ void SettingsDialog::saveSettings()
             settingsChanged = true;
         }
 
-        if(m_pPreferredBitrateSelector->currentIndex()!=m_prefBitrate)
+        if(m_HideCoverArt.isChecked() && !m_hideCoverart)
         {
-            m_pAppSettings->setValue("QSpot/PrefBitrate",m_pPreferredBitrateSelector->currentIndex());
+            m_pAppSettings->setValue("QSpot/HideCoverart",1);
+            settingsChanged = true;
+        }
+        else if(!m_HideCoverArt.isChecked() && m_hideCoverart)
+        { //credentials should not be saved, remove any existing values
+            m_pAppSettings->setValue("QSpot/HideCoverart",0);
+            settingsChanged = true;
+        }
+
+
+#ifdef Q_WS_MAEMO_5
+        selBitrate = m_pPreferredBitrateSelector->currentIndex();
+#else
+        selBitrate = m_PreferredBitrateCombo.currentIndex();
+#endif
+
+        if(selBitrate!=m_prefBitrate)
+        {
+            m_pAppSettings->setValue("QSpot/PrefBitrate",selBitrate);
+#ifdef Q_WS_MAEMO_5
             QMaemo5InformationBox::information(this,tr("Please restart QSpot for bitrate change to take effect!"));
+#else
+            Banner::information(this,tr("Please restart QSpot for bitrate change to take effect!"));
+#endif
         }
 
-        if(m_pUILangSelector->currentIndex()!=m_currUILang)
+#ifdef Q_WS_MAEMO_5
+        selUILang = m_pUILangSelector->currentIndex();
+#else
+        selUILang = m_UILangCombo.currentIndex();
+#endif
+
+        if(selUILang!=m_currUILang)
         {
-            m_pAppSettings->setValue("QSpot/language",m_UILangCodeList.at(m_pUILangSelector->currentIndex()));
+            m_pAppSettings->setValue("QSpot/language",m_UILangCodeList.at(selUILang));
+#ifdef Q_WS_MAEMO_5
             QMaemo5InformationBox::information(this,tr("Please restart QSpot for language change to take effect!"));
+#else
+            Banner::information(this,tr("Please restart QSpot for language change to take effect!"));
+#endif
+
         }
 
-        if(m_pOrientationSelector->currentIndex()!=m_currOrientation)
+#ifdef Q_WS_MAEMO_5
+        selOrientation = m_pOrientationSelector->currentIndex();
+#else
+        selOrientation = m_OrientationCombo.currentIndex();
+#endif
+
+        if(selOrientation!=m_currOrientation)
         {
-            m_pAppSettings->setValue("QSpot/displayOrientation",m_pOrientationSelector->currentIndex());
+            m_pAppSettings->setValue("QSpot/displayOrientation",selOrientation);
             settingsChanged = true;
         }
 
