@@ -24,7 +24,11 @@
 #include <QFont>
 #include <QTimer>
 #include <QTranslator>
-#include <QtMaemo5/QMaemo5InformationBox>
+#ifdef Q_WS_MAEMO_5
+    #include <QtMaemo5/QMaemo5InformationBox>
+#else
+    #include "Banner.h"
+#endif
 #include <QMessageBox>
 #include <qspotify_src/spotifysession.h>
 #include "logindialog.h"
@@ -39,12 +43,14 @@
 #include "OssoWrapper.h"
 #include "lastfmscrobbler.h"
 #include "DBusWrapper.h"
+#include "ConnectionManager.h"
 #include "global_defs.h"
+#include "Banner.h"
 
 
 //defines
 
-#define APP_VERSION "0.9.1-1" //application version string
+#define APP_VERSION "0.9.2-1" //application version string
 
 class MainWindow : public QMainWindow
 {
@@ -87,6 +93,8 @@ private:
 
     DBusWrapper* m_pDBusWrapper; //wrapper instance for D-bus interface
 
+    ConnectionManager* m_pConnMan; //connection manager instance pointer (handles e.g., online state change  / roaming notifications)
+
     LastFMScrobbler* m_pLastFMScrobbler; //Last.fm scrobbling instance
 
     QPushButton m_SearchBtn;
@@ -135,6 +143,8 @@ private:
 
     qint32 m_currOrientation; //current display orientation
 
+    bool m_reConnectReq; //TRUE in case re-connect to Spotify has been requested (used to prevent playlist metadata etc. to be reloaded in case connection is lost to Spotify backend)
+
     void logout(); //logout current user and display the login dialog
 
     void initAboutDialog(); //setup the application about dialog
@@ -153,6 +163,7 @@ private slots:
 
      void OnShowLogin();
      void OnLoggedIn(Spotify::Error error);
+     void OnLoggedOut();
      void OnPlaylistContainersReady(QList<Spotify::Playlist*> playlists);
      void OnPlaylistActivated(QModelIndex index);
      void OnLoginDialogRejected();
@@ -175,7 +186,10 @@ private slots:
      void OnScrobbleTrack(); //scrobble current track to Last.fm (and send scrobbles in queue)
      void OnOrientationChanged(); //device orientation changed (e.g, screen rotate)
      void OnDisplayStateChanged(bool state); //display state changed notification (i.e., true=ON, false=OFF)
+#ifdef Q_WS_MAEMO_5
      void OnHWZoomKeyPressed(quint32 keycode); //notification that HW zoom key has been pressed
+#endif
+     void OnSpotifyReconnectRequired(); //notification that current connection state has changed, and it is required to reconnect to the Spotify backend
 
 signals:
 
